@@ -26,13 +26,17 @@ of our resultsets. Current the following components are loaded:
 
 =item * L<DBIx::Class::Helper::ResultSet::Me>
 
+=item * L<DBIx::Class::Helper::ResultSet::SetOperations>
+
 =item * L<DBIx::Class::Helper::ResultSet::Shortcut>
 
 =back
 
 =cut
  
-__PACKAGE__->load_components( 'Helper::ResultSet::CorrelateRelationship',
-    'Helper::ResultSet::Me', 'Helper::ResultSet::Shortcut' );
+__PACKAGE__->load_components(
+    'Helper::ResultSet::CorrelateRelationship', 'Helper::ResultSet::Me',
+    'Helper::ResultSet::SetOperations',         'Helper::ResultSet::Shortcut'
+);
  
 1;
